@@ -57,6 +57,11 @@ class StateSpace():
         settling time in seconds, determines closed-loop bandwidth
     k_eso : float
         observer bandwidth
+    inc_form : float
+        toggle incremental form of ADRC, by default False. If the incremental
+        form is toggled, the controller will return the incrementation to the
+        current control signal. This value needs to be accumulated by the user.
+        Functionally identical to the non-incremental (normal) form.
     eso_init : tuple, optional
         initial state for the extended state observer, by default False
     r_lim : tuple, optional
@@ -74,6 +79,7 @@ class StateSpace():
                  b0: float,
                  t_settle: float,
                  k_eso: float,
+                 inc_form: bool = False,
                  eso_init: tuple = False,
                  r_lim: tuple = (None, None),
                  m_lim: tuple = (None, None),
@@ -158,6 +164,7 @@ class StateSpace():
         self._last_time = None
         self._last_output = None
         self._last_input = None
+        self.inc_form = inc_form
 
         self._linear_extended_state_observer()
 
@@ -170,8 +177,9 @@ class StateSpace():
         self.oB = self.Bd - self.L @ self.Cd @ self.Bd
         self.oC = self.Cd
 
-        # if self.inc_form is True:
-        #    self.oA = self.oA - np.eye(self.oA.shape[0])
+        if self.inc_form is True:
+            self.oA = self.oA - np.eye(self.oA.shape[0])
+            self.rkm1 = 0.
 
     def _update_eso(self, y: float, ukm1: float):
         """Update the linear extended state observer
@@ -183,9 +191,14 @@ class StateSpace():
         ukm1 : float
             Previous control signal u[k-1]
         """
+        if self.inc_form is False:
+            self.xhat = self.oA.dot(self.xhat) + self.oB.dot(
+                ukm1).reshape(-1, 1) + self.L.dot(y)
+        else:  # self.inc_form is True
+            self.xhat_delta = self.oA.dot(self.xhat) + self.oB.dot(
+                ukm1).reshape(-1, 1) + self.L.dot(y)
 
-        self.xhat = self.oA.dot(self.xhat) + self.oB.dot(
-            ukm1).reshape(-1, 1) + self.L.dot(y)
+            self.xhat = self.xhat + self.xhat_delta
 
     def _limiter(self, u_control: float) -> float:
         """Implements rate and magnitude limiter
@@ -200,11 +213,8 @@ class StateSpace():
         float
             float: rate and magnitude limited control signal
         """
-
+    
         # Limiting the rate of u (delta_u)
-        # delta_u = SaturatedInteger(self.r_lim[0], self.r_lim[1],
-        #                            u_control - self.ukm1)
-
         delta_u = saturation((self.r_lim[0], self.r_lim[1]),
                              u_control - self.ukm1)
 
@@ -312,10 +322,19 @@ class StateSpace():
             # Return last output of the controller if dt < delta
             return self._last_output
 
-        u = (self.Kp / self.b0) * r - self.w.T @ self.xhat
-        u = self._limiter(u)
         self._update_eso(y, u)
 
+        if self.inc_form is False:
+            u = (self.Kp / self.b0) * r - self.w.T @ self.xhat
+            u = self._limiter(u)
+        else:  # self.inc_form is True:
+            delta_r = r - self.rkm1
+            delta_u = ((self.Kp / self.b0) * delta_r
+                       - self.w.T @ self.xhat_delta)
+            u = delta_u
+
+            self.rkm1 = r
+
         self._last_output = float(u)
         self._last_time = now
         return float(u)
